# AutoTradingSystem

Trial project for deep learning trading model with ChatGPT-4

This project is an automatic trading system based on a Transformer and Reinforcement Learning hybrid model.

## Setup

1. Install the required packages: `pip install -r requirements.txt`  
2. Run the main script: `python src/main.py`

## Structure

my_project/  
│  
├── data/  
│   ├── raw/                   # Raw data goes here  
│   └── processed/             # Processed data goes here  
│  
├── notebooks/                 # Jupyter notebooks for exploratory analysis and prototyping  
│   ├── data_exploration.ipynb  
│   ├── data_preprocessing.ipynb  
│   ├── model_prototyping.ipynb  
│   ├── model_training.ipynb  
│   ├── hyperparameter_tuning.ipynb  
│   └── model_evaluation.ipynb  
│  
├── src/  
│   ├── agents/                # Agents module for HuggingFace's Transformers  
│   │   ├── \_\_init\_\_.py  
│   │   └── agent_example.py   # An example of a Transformer Agent  
│   │  
│   ├── data/                  # Data handling module  
│   │   ├── \_\_init\_\_.py  
│   │   ├── data_collection.py # Data collection scripts  
│   │   └── data_preprocessing.py # Data preprocessing scripts  
│   │  
│   ├── models/                # Models module  
│   │   ├── \_\_init\_\_.py  
│   │   ├── transformer_model.py # Transformer model script  
│   │   ├── rl_model.py         # RL model script  
│   │   └── trading_model.py    # Trading model script  
│   │  
│   ├── training/              # Training module  
│   │   ├── \_\_init\_\_.py  
│   │   └── train.py            # Training scripts  
│   │  
│   ├── evaluation/            # Evaluation module  
│   │   ├── \_\_init\_\_.py  
│   │   └── evaluate.py         # Evaluation scripts  
│   │  
│   ├── utils/                 # Utility module  
│   │   ├── \_\_init\_\_.py  
│   │   ├── utils.py            # Utility scripts (including seeding function)  
│   │   └── metrics.py          # Metrics computation scripts  
│   │  
│   └── main.py                # Main script to run the model  
│  
├── config/                    # Configuration files  
│   ├── transformer.json  
│   ├── rl.json  
│   └── training.json  
│  
├── tests/                     # Test module  
│   ├── \_\_init\_\_.py  
│   ├── test_data.py           # Tests for data collection and preprocessing  
│   ├── test_models.py         # Tests for model creation  
│   ├── test_training.py       # Tests for model training  
│   ├── test_evaluation.py     # Tests for model evaluation  
│   └── test_utils.py          # Tests for utility functions  
│  
├── .gitignore                 # Specifies which files should be ignored by Git  
├── README.md                  # Project description and instructions  
└── requirements.txt           # List of Python dependencies  
